@@ -24,14 +24,14 @@ def loadSegments():
     SegmentType.objects.bulk_create(ss)
 
 def loadSpeakers():
-    speakers = loadFile(fetch_media_resource("SpeakerInfo.txt"))
+    speakers = loadFile(fetch_buckeye_resource("SpeakerInfo.txt"))
     ss = []
     for s in speakers:
         ss.append(Speaker(Number=s['Number'],Age=s['Age'],Gender=s['Gender'],NumFormants=s['NFormants'],Ceiling=s['Ceiling']))
     Speaker.objects.bulk_create(ss)
 
 def loadCategories():
-    cats = loadFile(fetch_media_resource("CategoryInfo.txt"))
+    cats = loadFile(fetch_buckeye_resource("CategoryInfo.txt"))
     cs = []
     for s in cats:
         cs.append(Category(Label=s['Label'],Description=s['Description'],CategoryType=s['Type']))
@@ -197,7 +197,7 @@ def loadDialogs():
     speakers = Speaker.objects.all()
     ds = []
     for s in speakers:
-        files= os.listdir(fetch_media_resource("VIC/Speakers/"+unicode(s)))
+        files= os.listdir(fetch_buckeye_resource("Speakers/"+unicode(s)))
         dialogs=[]
         for j in xrange(len(files)):
             dialogs.append(files[j][3:5])
@@ -212,7 +212,7 @@ def processDialogs():
     dialogs = Dialog.objects.all()
     #check = 0
     for d in dialogs:
-        path = fetch_media_resource("Speakers/"+unicode(d.Speaker))
+        path = fetch_buckeye_resource("Speakers/"+unicode(d.Speaker))
         files= os.listdir(path)
         wordFiles = []
         for f in files:
@@ -238,14 +238,13 @@ def doReset(logfilename):
 
 @task()
 def combineResults(allout):
-    f = open(fetch_media_resource("Results/Buckeye/analysis.txt"),'w')
-    f.write("\t".join(allout[0][0].keys()))
-    f.write("\n")
-    for l in allout:
-        for line in l:
-            f.write("\t".join(map(str,line.values())))
-            f.write("\n")
-    f.close()
+    with open(fetch_media_resource("Results/Buckeye/analysis.txt"),'w') as f:
+        f.write("\t".join(allout[0][0].keys()))
+        f.write("\n")
+        for l in allout:
+            for line in l:
+                f.write("\t".join(map(str,line.values())))
+                f.write("\n")
 
 @task()
 def AnalyzeSpeaker(baseqs,speakNum,form):
@@ -263,7 +262,7 @@ def AnalyzeSpeaker(baseqs,speakNum,form):
             #updatelogfile(logfilename, cur)
         allout.extend(w.getAnalysisLines(form))
     return allout
-    #addResults(allout,fetch_media_resource("Results/Buckeye/analysis_%s.txt"%speakNum))
+    #addResults(allout,fetch_buckeye_resource("Results/Buckeye/analysis_%s.txt"%speakNum))
 
     #updatelogfile(logfilename, "All done!")
 
@@ -317,12 +316,12 @@ def doBasicAnalysis(logfilename,form):
     res.get()
 #@task_success.connect(sender=doBasicAnalysis)
 #def consolidateResultFiles():
-#    outs = os.listdir(fetch_media_resource("Results/Buckeye"))
-#    os.remove(fetch_media_resource("Results/Buckeye/analysis.txt"))
+#    outs = os.listdir(fetch_buckeye_resource("Results/Buckeye"))
+#    os.remove(fetch_buckeye_resource("Results/Buckeye/analysis.txt"))
 #    head = False
-#    allout = open(fetch_media_resource("Results/Buckeye/analysis.txt"),'w')
+#    allout = open(fetch_buckeye_resource("Results/Buckeye/analysis.txt"),'w')
 #    for fn in outs:
-#        f = open(fetch_media_resource("Results/Buckeye/%s"%fn))
+#        f = open(fetch_buckeye_resource("Results/Buckeye/%s"%fn))
 #        ls = f.read().splitlines()
 #        if not head:
 #            allout.write(ls[0]+"\n")
